<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
import { dateRangeOptions } from '@/utils/options'
import CustomDateRange from '@/components/custom-date-range.vue'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/settlement/list',
        hasNew: false,
        hasEdit: false,
        hasDelete: false,
        onResetView: (row) => {
          this.$router.push(`${this.$route.path}/${row.id}`)
        },
        operationAttrs: {
          width: 120,
          fixed: 'right',
        },
        columns: [
          {
            label: '结算人',
            prop: 'userName',
            minWidth: 150,
            fixed: 'left',
          },
          {
            label: '结算金额(元)',
            prop: 'settlementAmount',
            minWidth: 120,
            fixed: 'left',
          },
          { label: '订单数量', prop: 'orderNum', minWidth: 100 },
          { label: '买家数量', prop: 'customerNum', minWidth: 100 },
          { label: '商品数量', prop: 'flowerNum', minWidth: 100 },
          { label: '结算合计(元)', prop: 'totalAmount', minWidth: 120 },
          { label: '结算均价(元)', prop: 'price', minWidth: 120 },
          { label: '质检扣款(元)', prop: 'checkFee', minWidth: 120 },
          { label: '售后理赔(元)', prop: 'salesFee', minWidth: 120 },
          { label: '服务费(元)', prop: 'serviceFee', minWidth: 120 },
          { label: '集货站运费(元)', prop: 'stationFee', minWidth: 120 },
          { label: '结算类型', prop: 'typeStr', minWidth: 120 },
          { label: '结算状态', prop: 'statusStr', minWidth: 120 },
          { label: '结算时间', prop: 'transferTime', minWidth: 180 },
        ],
        searchFormAttrs: {
          labelWidth: 'auto',
        },
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '结算类型：',
                id: 'type',
                type: 'bus-radio',
                el: {
                  hasAll: true,
                  childType: 'el-radio-button',
                  code: 'SETTLEMENT_TYPE',
                },
                default: '',
                span: 24,
                searchImmediately: true,
              },
              {
                label: '结算状态：',
                id: 'status',
                type: 'bus-radio',
                el: {
                  hasAll: true,
                  childType: 'el-radio-button',
                  code: 'SETTLEMENT_STATUS',
                },
                default: '',
                span: 24,
                searchImmediately: true,
              },
              {
                label: '结算日期：',
                id: 'dateType',
                component: CustomDateRange,
                el: {
                  options: dateRangeOptions,
                },
                searchImmediately: true,
                commonFormat: true,
                commonFormatProps: ['dateType', 'startDateStr', 'endDateStr'],
                span: 24,
              },
            ],
          },
        ],
        extraButtons: [
          {
            text: '结算',
            show: (row) => row.status === 'PENDING' || row.status === 'FAILED',
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要结算吗？')
                const { code } = await this.$elBusHttp.request(
                  'flower/api/settlement/list/transfer',
                  {
                    params: {
                      id: row.id,
                    },
                  }
                )
                if (code === 0) {
                  this.$message.success('结算成功')
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '结算列表',
    }
  },
}
</script>

<style lang="scss" scoped>
::v-deep {
  .el-bus-crud__filter__action {
    display: none;
  }
}
</style>
